import React, {Component} from 'react';
import { View } from 'react-native';
import { connect } from 'react-redux';
import {RTCView} from 'react-native-webrtc';

class MainVideo extends Component{
    
    constructor(props){
        super(props);
    }

    componentDidMount(){
        this.updateDominantVideoId();
    }

    componentDidUpdate(){
        this.updateDominantVideoId();
    }

    updateDominantVideoId(){
        if(this.props.dominantVideoId == null && this.props.remoteTracks.length != 0){
            if(this.props.remoteTracks[0].video != null){
                this.props.updateDominantVideoId(this.props.remoteTracks[0].ownerId);
            }
        }
    }

    render(){
        return(
            <View id="rt_container" style={this.style.rt_container}>
                {
                    this.props.remoteTracks.map((tracks,index) => {
                        if(tracks.ownerId == this.props.dominantVideoId && tracks.video != null){
                            return(
                                <RTCView
                                    key={index}
                                    objectFit = "cover"
                                    streamURL = { tracks.video.getOriginalStream().toURL() }
                                    style={{ flex: 1 , height: '100%', width: '100%' }}
                                    zOrder={0}
                                />
                            )    
                        }
                    })
                }
                {
                    this.props.remoteTracks.length == 0 ? <RTCView objectFit = "cover" streamURL = { this.props.localUrl } style={{ flex: 1 , height: '100%', width: '100%' }} zOrder={0} /> : this.props.dominantVideoId == 'localVideo' ? <RTCView objectFit = "cover" streamURL = { this.props.localUrl } style={{ flex: 1 , height: '100%', width: '100%' }} zOrder={0} /> : null
                }
            </View>
        )
    }

    style = {
        rt_container: { height: '100%', width: '100%', position: 'absolute', left: 0, top: 0, zIndex: 1 }
    };
}

function mapStateToProps (state) {
    return {
        localUrl: state.url.localUrl,
        localTrackId: state.url.localTrackId,
        localTracks: state.tracks.localTracks,
        remoteTracks: state.tracks.remoteTracks,
        dominantVideoId: state.tracks.dominantVideoId
    }
}

function mapDispatchToProps(dispatch){
    return{
        updateDominantVideoId: (id) => dispatch(data.updateDominantVideoId(id))
    }
}


export default connect(mapStateToProps, mapDispatchToProps)(MainVideo)